Group {
  D = Region[1000];
  FAR  = Region[2000];
  ROD1 = Region[2001];
  ROD2 = Region[2002];
}

Function {
  eps[] = 1;
  rho[] = 1;
}

Jacobian {
  { Name V;
    Case {
      { Region All; Jacobian Vol; }
    }
  }
}

Integration {
  { Name I;
    Case {
      { Type Gauss;
        Case {
          { GeoElement Point; NumberOfPoints  1; }
          { GeoElement Line; NumberOfPoints  3; }
          { GeoElement Triangle; NumberOfPoints  3; }
          { GeoElement Quadrangle; NumberOfPoints  4; }
          { GeoElement Tetrahedron; NumberOfPoints  4; }
          { GeoElement Hexahedron; NumberOfPoints  6; }
          { GeoElement Prism; NumberOfPoints  9; }
          { GeoElement Pyramid; NumberOfPoints  8; }
	}
      }
    }
  }
}

Constraint {
  { Name BC; Type Assign;
    Case {
      { Region FAR ; Value 0.; }
      { Region ROD1; Value -1.; }
      { Region ROD2; Value  1.; }
    }
  }
}

FunctionSpace {
  { Name E1; Type Form0;
    BasisFunction {
      { Name sn; NameOfCoef vn; Function BF_Node; Support D; Entity NodesOf[All]; }
      { Name sn2; NameOfCoef vn2; Function BF_Node_2E; Support D; Entity NodesOf[All]; }
    }
    Constraint {
      { NameOfCoef vn; EntityType NodesOf; NameOfConstraint BC; }
      { NameOfCoef vn2; EntityType NodesOf; NameOfConstraint BC; }
    }
  }
}

Formulation {
  { Name Poisson; Type FemEquation;
    Quantity {
      { Name v; Type Local; NameOfSpace E1; }
    }
    Equation {
      Galerkin { [ eps[] * Dof{d v}, {d v} ] ; In D; Jacobian V; Integration I; }
      Galerkin { [ rho[], {v} ] ; In D; Jacobian V; Integration I; }
    }
  }
}

Resolution {
  { Name EleSta_v;
    System {
      { Name Sys_Ele; NameOfFormulation Poisson; }
    }
    Operation {
      Generate[Sys_Ele]; Solve[Sys_Ele]; SaveSolution[Sys_Ele];
    }
  }
}

PostProcessing {
  { Name EleSta_v; NameOfFormulation Poisson;
    PostQuantity {
      { Name v; Value { Term { [ {v} ]; In D; Jacobian V; } } }
      { Name e; Value { Term { [ -{d v} ]; In D; Jacobian V; } } }
    }
  }
}

PostOperation {
  { Name EleSta_v; NameOfPostProcessing EleSta_v;
    Operation {
      Print[ e, OnElementsOf D, File "EleSta_v_e.pos", Depth 2 ];
      Print[ v, OnElementsOf D, File "MagSta_v_v.pos", Depth 2 ];
    }
  }
}
